function [zeta_average] = Eulerian_transition_velocityChange(R,gamma,a,GS,t_fixed,t_trans,delta_t,lim)
% Eulerian_transition_velocityChange.m calculates the relative rate of a velocity change of c-EIs
% R: (domain) circle radius
% gamma: vortex strength
% a: fixed vortex centre
% GS: grid size
% t_fixed: time spent on stationary states
% t_trans: time spent on transition
% delta_t: time interval in integration
% lim: circle radius around the fixed/moving vortex centre to be removed

tic

% moving vortex centre
a_t = @(m,t) ((-1)^(m+1))*a*(1-2*t/(t_trans/2));

% a period
t_total = t_fixed+t_trans;

% Initialise
n=round((t_trans/2)/delta_t+1);
delta_w_t = zeros(2,n);
zeta_sum = 0;
zeta_num = 0;

for x = -R:GS:R
    for y = -R:GS:R
        % calculation only inside the circle
        if abs(x+1i*y) > R
            continue
        end
        
        % compute t average
        for i=1:2 % 1 iteration 
            delta_w_ind = 1; % index
            % transition
            for t_transition=0:delta_t:t_trans/2
                % exclude the region around the fixed/moving vortex centre
                if norm([x,y]-[a_t(i,t_transition),0]) <= lim
                    delta_w_ind = delta_w_ind + 1;
                    continue
                end
                
                % avoid moving vortex centre at domain centre
                if a_t(i,t_transition) == 0
                    t_tr=t_transition+delta_t/2;
                else
                    t_tr=t_transition;
                end
                
                if t_transition == 0
                    % velocity vector
                    vel1 = blinkingVortexVF(R,gamma,x,y,a_t(i,t_tr)); 
                    v1 = [real(vel1),imag(vel1)];
                    continue
                end
                
                % velocity vector
                vel2 = blinkingVortexVF(R,gamma,x,y,a_t(i,t_tr));
                v2 = [real(vel2),imag(vel2)];
                
                % relative rate of a velocity change
                delta_w=norm(v2-v1)/(norm(v2)+norm(v1));
                
                % Singularity
                if isnan(delta_w)
                    delta_w_ind = delta_w_ind + 1;
                else
                    delta_w_t(i,delta_w_ind) = delta_w;
                    delta_w_ind = delta_w_ind + 1;
                end
            end     
        end
        
        % integration
        sum_delta_w1 = sum(delta_w_t(1,2:end-1),'all');
        sum_delta_w2 = sum(delta_w_t(2,2:end-1),'all');
        sum_delta_w_col = sum(delta_w_t,1);
        
        sum_con = (sum_delta_w_col(1)+sum_delta_w_col(end)+2*(sum_delta_w1+sum_delta_w2))*delta_t/2;
        delta_w_t_average = sum_con/t_total;
        
        zeta_sum = zeta_sum + delta_w_t_average;
        zeta_num = zeta_num + 1;    
    end
end

zeta_average = zeta_sum/zeta_num;

toc

beep
end